@@ -3,19 +3,21 @@ from matplotlib import pyplot as plt
 
 
 def mut_exclusive(size=15, fill_color='skyblue', bg_color='white', font_size=20,
-                  title='Mutually exclusive: A∩B=∅', set_a='A', set_b='B'):
+                  title='Mutually exclusive: A∩B=∅', set_a='A', set_b='B', text_size=15):
     """
     Mutually exclusive Venn diagram
 
     parameters
     ----------
-    size: 15
-    fill_color: default 'skyblue'
-    bg_color: default 'white'
-    font_size: default 20
-    title: default 'Mutually exclusive: A∩B=∅'
-    set_a: default 'A'
-    set_b: default 'B'
+
+    size: Set the figure size. The default value is 15.
+    fill_color: Set the filling color. The default value is 'skyblue'.
+    bg_color: Set the background color. The default value is 'white'.
+    font_size: Set the title font size. The default value is 20.
+    title: Set the title. The default value is 'Mutually exclusive: A∩B=∅'
+    set_a: Set the set name for the left diagram. The default value is 'A'.
+    set_b: Set the set name for the left diagram. The default value is 'B'.
+    text_size: Set the text size. The default value is 15.
 
     example
     -------
@@ -44,4 +46,5 @@ def mut_exclusive(size=15, fill_color='skyblue', bg_color='white', font_size=20,
         if txt:
             txt.set_text('')
 
+    plt.rc('font', size=text_size)
     plt.show()
